@@ -14,19 +14,22 @@ from reamber.sm.lists.notes.SMHoldList import SMHoldList
 
 
 class OsuToSM:
+    OFFSET = 68
+
     @staticmethod
-    def convert(osu: OsuMap) -> SMMapSet:
+    def convert(osu: OsuMap, assertKeys=True) -> SMMapSet:
         """ Converts Osu to a SMMapset Obj
 
         Note that each osu map object will create a separate mapset, they are not merged
 
-        :param osu: Osu Map
-        :return: SM Mapset
+        :param osu:
+        :param assertKeys: Adds an assertion to verify that Quaver can support this key mode
+        :return:
         """
 
-        # I haven't tested with non 4 keys, so it might explode :(
+        if assertKeys: assert osu.circleSize == 4
 
-        assert osu.circleSize == 4
+        print(osu.bpms.firstOffset())
 
         hits: List[SMHit] = []
         holds: List[SMHold] = []
@@ -51,7 +54,7 @@ class OsuToSM:
             background=osu.backgroundFileName,
             sampleStart=osu.previewTime,
             sampleLength=10,
-            offset=osu.notes.firstOffset(),
+            offset=-(osu.bpms.firstOffset() + OsuToSM.OFFSET),
             maps=[
                 SMMap(
                     chartType=SMMapChartTypes.DANCE_SINGLE,
