@@ -13,6 +13,8 @@ from reamber.sm.SMMapSet import SMMapSet, SMMap
 
 
 class SMToOsu:
+    OFFSET = 68
+
     @staticmethod
     def convert(sm: SMMapSet) -> List[OsuMap]:
         """ Converts a SMMapset to possibly multiple osu maps
@@ -20,8 +22,8 @@ class SMToOsu:
         Note that a mapset contains maps, so a list would be expected.
         SMMap conversion is not possible due to lack of SMMapset Metadata
 
-        :param sm: The MapSet
-        :return: List of Osu Maps
+        :param sm:
+        :return:
         """
 
         # I haven't tested with non 4 keys, so it might explode :(
@@ -60,5 +62,6 @@ class SMToOsu:
                 notes=OsuNotePkg(hits=OsuHitList(hits),
                                  holds=OsuHoldList(holds))
             )
+            osuMap.addOffset(-(2 * sm.offset + SMToOsu.OFFSET), inplace=True)
             osuMapSet.append(osuMap)
         return osuMapSet
