@@ -1,10 +1,12 @@
 from __future__ import annotations
-from reamber.sm.lists.notes.SMNoteList import SMNoteList
-from reamber.sm.SMFakeObj import SMFakeObj
+
 from typing import List
 
+from reamber.sm.SMFake import SMFake
+from reamber.sm.lists.notes.SMNoteList import SMNoteList
 
-class SMFakeList(List[SMFakeObj], SMNoteList):
+
+class SMFakeList(List[SMFake], SMNoteList):
 
     def _upcast(self, objList: List = None) -> SMFakeList:
         """ This is to facilitate inherited functions to work
@@ -14,5 +16,5 @@ class SMFakeList(List[SMFakeObj], SMNoteList):
         """
         return SMFakeList(objList)
 
-    def data(self) -> List[SMFakeObj]:
+    def data(self) -> List[SMFake]:
         return self
