@@ -1,9 +1,10 @@
-from reamber.base.lists.notes.NoteList import NoteList
-from reamber.base.NoteObj import NoteObj
-from typing import List
 from abc import ABC
+from typing import List
+
+from reamber.base.Note import Note
+from reamber.base.lists.notes.NoteList import NoteList
 
 
 class SMNoteList(NoteList, ABC):
-    def data(self) -> List[NoteObj]: pass
+    def data(self) -> List[Note]: pass
 
